Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(133)

Unified Diff: build/install-build-deps.sh

Issue 302083016: Adding additional packages for nacl and naclports to install-build-deps.sh (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: merge Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: build/install-build-deps.sh
diff --git a/build/install-build-deps.sh b/build/install-build-deps.sh
index f3b7eba2c78d9386548ccab4073b97addeadeca4..e76ef08cbf3f3f69bee5e1b3a32abe69c4a4ae31 100755
--- a/build/install-build-deps.sh
+++ b/build/install-build-deps.sh
@@ -142,8 +142,16 @@ arm_list="libc6-dev-armhf-cross
linux-libc-dev-armhf-cross
g++-arm-linux-gnueabihf"
-# Packages to build standalone NaCl and all its toolchains.
-nacl_list="g++-mingw-w64-i686 libtinfo-dev:i386"
+# Packages to build NaCl, its toolchains, and its ports.
+nacl_list="bison cmake xvfb gawk texinfo autoconf libtool
+ libssl0.9.8:i386 lib32z1-dev
+ libgpm2:i386 libncurses5:i386
+ g++-mingw-w64-i686 libtinfo-dev:i386 libglib2.0-0:i386 libnss3:i386
+ libgconf-2-4:i386 libfontconfig:i386
+ libpango1.0-0:i386 libxi6:i386 libxcursor1:i386 libxcomposite1:i386
+ libasound2:i386 libxdamage1:i386 libxtst6:i386 libxrandr2:i386
+ libcap2:i386 libudev0:i386 libgtk2.0-0:i386 libxss1:i386
+ libexif12:i386 libgl1-mesa-glx:i386"
# Some package names have changed over time
if package_exists ttf-mscorefonts-installer; then
@@ -260,9 +268,9 @@ else
fi
if test "$do_inst_nacl" = "1"; then
- echo "Including standalone NaCl dependencies."
+ echo "Including NaCl, NaCl toolchain, NaCl ports dependencies."
else
- echo "Skipping standalone NaCl dependencies."
+ echo "Skipping NaCl, NaCl toolchain, NaCl ports dependencies."
nacl_list=
fi
@@ -371,6 +379,18 @@ else
echo "Skipping installation of Chrome OS fonts."
fi
+if test "$do_inst_nacl" = "1"; then
+ echo "Installing symbolic links for NaCl."
+ if [ ! -r /usr/lib/i386-linux-gnu/libcrypto.so ]; then
+ sudo ln -fs libcrypto.so.0.9.8 /usr/lib/i386-linux-gnu/libcrypto.so
+ fi
+ if [ ! -r /usr/lib/i386-linux-gnu/libssl.so ]; then
+ sudo ln -fs libssl.so.0.9.8 /usr/lib/i386-linux-gnu/libssl.so
+ fi
+else
+ echo "Skipping symbolic links for NaCl."
+fi
+
# Install 32bit backwards compatibility support for 64bit systems
if file /sbin/init | grep -q 'ELF 64-bit'; then
if test "$do_inst_lib32" != "1"
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698